@@ -178,7 +178,7 @@ void RubySupportPart::parse(const QString &fileName)
   QTextStream stream(&f);
 
   QRegExp classre("^\\s*(class|module)\\s+([A-Z][A-Za-z0-9_]+)\\s*(<\\s*([A-Z][A-Za-z0-9_:]+))?$");
-  QRegExp methodre("^\\s*def\\s+([A-Z][A-Za-z0-9_:]+\\.)?([A-Za-z0-9_]+[!?=]?|\\[\\]=?|\\*\\*||\\-|[!~+*/%&|><^]|>>|<<||<=>|<=|>=|==|===|!=|=~|!~).*$");
+  QRegExp methodre("^\\s*def\\s+(([A-Z][A-Za-z0-9_:]+|self)\\.)?([A-Za-z0-9_]+[!?=]?|\\[\\]=?|\\*\\*||\\-|[!~+*/%&|><^]|>>|<<||<=>|<=|>=|==|===|!=|=~|!~).*$");
   QRegExp accessre("^\\s*(private|protected|public)\\s*((:([A-Za-z0-9_]+[!?=]?|\\[\\]=?|\\*\\*||\\-|[!~+*/%&|><^]|>>|<<||<=>|<=|>=|==|===|!=|=~|!~),?\\s*)*)$");
   QRegExp attr_accessorre("^\\s*(attr_accessor|attr_reader|attr_writer)\\s*((:([A-Za-z0-9_]+),?\\s*)*)$");
   QRegExp symbolre(":([^,]+),?");
@@ -223,17 +223,17 @@ void RubySupportPart::parse(const QString &fileName)
 	  lastAccess = CodeModelItem::Public;
     } else if (methodre.search(line) != -1) {
       FunctionDom methodDecl;
-      if ( lastClass != 0 && lastClass->hasFunction( methodre.cap(2) ) ) {
-        FunctionList methods = lastClass->functionByName( methodre.cap(2) );
+      if ( lastClass != 0 && lastClass->hasFunction( methodre.cap(3) ) ) {
+        FunctionList methods = lastClass->functionByName( methodre.cap(3) );
 	    methodDecl = methods[0];
 	  } else {
         methodDecl = codeModel()->create<FunctionModel>();
         methodDecl->setFileName( fileName );
         methodDecl->setStartPosition( lineNo, 0 );
-        methodDecl->setName(methodre.cap(2));
+        methodDecl->setName(methodre.cap(3));
 	  }
       FunctionDefinitionDom method = codeModel()->create<FunctionDefinitionModel>();
-      method->setName(methodre.cap(2));
+      method->setName(methodre.cap(3));
       kdDebug() << "Add method: " << method->name() << endl;
       method->setFileName( fileName );
       method->setStartPosition( lineNo, 0 );
@@ -361,9 +361,10 @@ void RubySupportPart::parse(const QString &fileName)
 			}
 		  }
 		} else {
-          if ( !lastClass->hasFunction(symbolre.cap(1)) ) { 
-		    QStringList scope( lastClass->name() );
-			if (attr == "attr_accessor" || attr == "attr_reader") {
+ 		    QStringList scope( lastClass->name() );
+			if (	!lastClass->hasFunction(symbolre.cap(1))
+					&& (attr == "attr_accessor" || attr == "attr_reader") ) 
+			{
               FunctionDefinitionDom method = codeModel()->create<FunctionDefinitionModel>();
               method->setName(symbolre.cap(1));
               kdDebug() << "Add method: " << method->name() << endl;
@@ -374,7 +375,9 @@ void RubySupportPart::parse(const QString &fileName)
               lastClass->addFunctionDefinition( method );
 			}
 			
-			if (attr == "attr_accessor" || attr == "attr_writer") {
+            if (	!lastClass->hasFunction(symbolre.cap(1) + "=")
+					&& (attr == "attr_accessor" || attr == "attr_writer") ) 
+			{
               FunctionDefinitionDom method = codeModel()->create<FunctionDefinitionModel>();
               method->setName(symbolre.cap(1) + "=");
               kdDebug() << "Add method: " << method->name() << endl;
@@ -386,7 +389,6 @@ void RubySupportPart::parse(const QString &fileName)
 			}
 			
             pos  += symbolre.matchedLength();
-		  }
         }
 	  }	  
    } else if (variablere.search(line) != -1 && lastClass != 0) {
