@@ -27,7 +27,6 @@
 #include <kapplication.h>
 #include <kactionclasses.h>
 #include <kpopupmenu.h>
-#include <kiconloader.h>
 
 #include "kdevcore.h"
 #include "kdevmainwindow.h"
@@ -50,15 +49,17 @@
 #define PROJECTSETTINGSPAGE 1
 #define GLOBALSETTINGSPAGE 2
 
-static const KAboutData data("kdevfilecreate", I18N_NOOP("New File Wizard"), "1.0");
+#include "kdevplugininfo.h"
+
+static const KDevPluginInfo data("kdevfilecreate");
 
 typedef KDevGenericFactory<FileCreatePart> FileCreateFactory;
-K_EXPORT_COMPONENT_FACTORY( libkdevfilecreate, FileCreateFactory( &data ) )
+K_EXPORT_COMPONENT_FACTORY( libkdevfilecreate, FileCreateFactory( data ) )
 
 using namespace FileCreate;
 
 FileCreatePart::FileCreatePart(QObject *parent, const char *name, const QStringList & )
-    : KDevCreateFile("FileCreate", "wizard", parent, name ? name : "FileCreatePart"), m_selectedWidget(-1), m_useSideTab(true), m_subPopups(0)
+    : KDevCreateFile(&data, parent, name ? name : "FileCreatePart"), m_selectedWidget(-1), m_useSideTab(true), m_subPopups(0)
 {
   setInstance(FileCreateFactory::instance());
   setXMLFile("kdevpart_filecreate.rc");
@@ -67,13 +68,13 @@ FileCreatePart::FileCreatePart(QObject *parent, const char *name, const QStringL
   connect( core(), SIGNAL(projectClosed()), this, SLOT(slotProjectClosed()) );
   
 	_configProxy = new ConfigWidgetProxy( core() );
-	_configProxy->createProjectConfigPage( i18n("New File Wizard"), PROJECTSETTINGSPAGE, icon() );
-	_configProxy->createGlobalConfigPage( i18n("New File Wizard"), GLOBALSETTINGSPAGE, icon() );
+	_configProxy->createProjectConfigPage( i18n("File Templates"), PROJECTSETTINGSPAGE, info()->icon() );
+	_configProxy->createGlobalConfigPage( i18n("File Templates"), GLOBALSETTINGSPAGE, info()->icon() );
 	connect( _configProxy, SIGNAL(insertConfigWidget(const KDialogBase*, QWidget*, unsigned int )), 
 		this, SLOT(insertConfigWidget(const KDialogBase*, QWidget*, unsigned int )) );
 
 
-  KToolBarPopupAction * newAction = new KToolBarPopupAction( i18n("&New"), "file_new", CTRL+Qt::Key_N, this, SLOT(slotNewFile()), actionCollection(), "file_new");
+  KToolBarPopupAction * newAction = new KToolBarPopupAction( i18n("&New"), "filenew", CTRL+Qt::Key_N, this, SLOT(slotNewFile()), actionCollection(), "file_new");
   newAction->setWhatsThis( i18n("<b>New file</b><p>Creates a new file. Also adds it the project if the <b>Add to project</b> checkbox is turned on.") );
   newAction->setToolTip( i18n("Create a new file") );
   m_newPopupMenu = newAction->popupMenu();
@@ -191,7 +192,7 @@ void FileCreatePart::slotAboutToShowNewPopupMenu()
 					KIcon::DefaultState, NULL, true);
 				m_newPopupMenu->insertItem(iconPix, filetype->name(), this,
 					SLOT(slotNewFilePopup(int)), 0, ++id );
-				m_newPopupMenu->setItemParameter( id, (int)filetype );
+				m_newPopupMenu->setItemParameter( id, (long)filetype );
 			} else
 			{
 				KPopupMenu* subMenu = NULL;
@@ -206,7 +207,7 @@ void FileCreatePart::slotAboutToShowNewPopupMenu()
 							KIcon::DefaultState, NULL, true);
 						subMenu->insertItem(iconPix, subtype->name(), this,
 							SLOT(slotNewFilePopup(int)), 0, ++id );
-						subMenu->setItemParameter( id, (int)filetype );
+						subMenu->setItemParameter( id, (long)subtype );
 					}
 				}
 				if( subMenu )
