@@ -17,18 +17,18 @@
 #include <qstringlist.h>
 
 class QListView;
+class QComboView;
 class KURLLabel;
 
-
+/**
+Plugin selection widget.
+*/
 class PartSelectWidget : public QWidget
 {
     Q_OBJECT
 
 public:
-    /* for selection of project parts */
     PartSelectWidget( QDomDocument &projectDom, QWidget *parent=0, const char *name=0 );
-    /* for selection of global parts */
-    PartSelectWidget( QWidget *parent=0, const char *name=0 );
     ~PartSelectWidget();
 
 public slots:
@@ -40,23 +40,23 @@ signals:
 private slots:
     void itemSelected( QListViewItem * );
     void openURL( const QString & );
+    void selectProfile(QListViewItem* item);
+    void setAsDefault();
 
 private:
-    enum Scope { Global, Project };
-
     void init();
-    void readGlobalConfig();
-    void saveGlobalConfig();
     void readProjectConfig();
     void saveProjectConfig();
+//    void fillProfilesList();
 
     QDomDocument m_projectDom;
-    Scope _scope;
 
     QListView * _pluginList;
+//    QComboView *_pluginProfile;
     QLabel * _pluginDescription;
     KURLLabel * _urlLabel;
 
+//    QString _profile;
 };
 
 #endif
