@@ -1,5 +1,6 @@
 #include <qfile.h>
 #include <qfileinfo.h>
+#include <qdir.h>
 #include <qdom.h>
 #include <qstringlist.h>
 #include <qptrlist.h>
@@ -202,16 +203,24 @@ void ProjectManager::loadDefaultProject()
   }
 }
 
-bool ProjectManager::loadProject(const KURL &url)
+bool ProjectManager::loadProject(const KURL &projectURL)
 {
+  KURL url = projectURL;
+  
   if (!url.isValid())
     return false;
 
+  if (url.isLocalFile()) 
+  {
+    QDir dir(url.path());
+    url.setPath(dir.canonicalPath());
+  }
+
   // reopen the already opened project?
   if( url.path() == projectFile().path() )
   {
     if (KMessageBox::questionYesNo(TopLevel::getInstance()->main(),
-        i18n("Are you sure you want to reopen the current project?")) == KMessageBox::No)
+        i18n("Are you sure you want to reopen the current project?"), QString::null, i18n("Reopen"), i18n("Do Not Reopen")) == KMessageBox::No)
       return false;
   }
 
@@ -514,7 +523,7 @@ bool ProjectManager::loadLanguageSupport(const QString& lang)
 
   KTrader::OfferList languageSupportOffers =
     KTrader::self()->query(QString::fromLatin1("KDevelop/LanguageSupport"),
-                           QString::fromLatin1("[X-KDevelop-Language] == '%1' and [X-KDevelop-Version] == %2").arg(m_info->m_language).arg(KDEVELOP_PLUGIN_VERSION));
+                           QString::fromLatin1("[X-KDevelop-Language] == '%1' and [X-KDevelop-Version] == %2").arg(lang).arg(KDEVELOP_PLUGIN_VERSION));
 
   if (languageSupportOffers.isEmpty()) {
     KMessageBox::sorry(TopLevel::getInstance()->main(),
@@ -533,7 +542,7 @@ bool ProjectManager::loadLanguageSupport(const QString& lang)
   if ( !langSupport ) {
     KMessageBox::sorry(TopLevel::getInstance()->main(),
         i18n("Could not create language plugin for %1.")
-            .arg(m_info->m_language));
+            .arg(lang));
     return false;
   }
 
